#!/usr/bin/env python

"""
Test objects.

Copyright (C) 2017 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.data import parse_string, Object
from imiptools.dates import get_datetime

# Define a parent object plus recurrence instances.

parent_str = """\
BEGIN:VEVENT
ORGANIZER:mailto:paul.boddie@example.com
ATTENDEE;RSVP=TRUE:mailto:resource-room-confroom@example.com
DTSTAMP:20141009T182400Z
DTSTART;TZID=Europe/Oslo:20141010
DTEND;TZID=Europe/Oslo:20141011
RRULE:FREQ=MONTHLY;BYDAY=2FR;COUNT=3
SUMMARY:Recurring event
UID:event4@example.com
END:VEVENT
"""

modification_str = """\
BEGIN:VEVENT
ORGANIZER:mailto:paul.boddie@example.com
ATTENDEE;RSVP=TRUE:mailto:resource-room-confroom@example.com
DTSTAMP:20141009T182500Z
DTSTART;TZID=Europe/Oslo:20141115
DTEND;TZID=Europe/Oslo:20141116
SUMMARY:Recurring event
UID:event4@example.com
RECURRENCE-ID;TZID=Europe/Oslo:20141114
SEQUENCE:2
END:VEVENT
"""

cancellation_str = """\
BEGIN:VEVENT
ORGANIZER:mailto:paul.boddie@example.com
ATTENDEE;RSVP=TRUE:mailto:resource-room-confroom@example.com
DTSTAMP:20141009T182500Z
DTSTART;TZID=Europe/Oslo:20141213
DTEND;TZID=Europe/Oslo:20141214
SUMMARY:Recurring event
UID:event4@example.com
RECURRENCE-ID;TZID=Europe/Oslo:20141213
SEQUENCE:2
END:VEVENT
"""

# Parse the objects.

parent = Object(parse_string(parent_str, "utf-8"))
modification = Object(parse_string(modification_str, "utf-8"))
cancellation = Object(parse_string(cancellation_str, "utf-8"))

# Set the recurrence objects in the parent.

parent.set_modifying([modification])
parent.set_cancelling([cancellation])

# Obtain periods within a window of time.

tzid = parent.get_tzid()
start = get_datetime("20141001T000000", {"TZID" : tzid})
end = get_datetime("20151001", {"TZID" : tzid})

for p in parent.get_periods(start, end):
    print p

print "----"

for old, new in parent.get_updated_periods(start, end):
    print old
    print new
    print

print "----"

for p in parent.get_active_periods(start, end):
    print p

# vim: tabstop=4 expandtab shiftwidth=4
